@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Representer;
 
-our $VERSION = '0.020'; # VERSION
+our $VERSION = '0.023'; # VERSION
 
 use Scalar::Util qw/ reftype blessed refaddr /;
 
@@ -13,14 +13,23 @@ use YAML::PP::Common qw/
     YAML_LITERAL_SCALAR_STYLE YAML_FOLDED_SCALAR_STYLE
     YAML_FLOW_SEQUENCE_STYLE YAML_FLOW_MAPPING_STYLE
     YAML_BLOCK_MAPPING_STYLE YAML_BLOCK_SEQUENCE_STYLE
+    PRESERVE_ALL PRESERVE_ORDER PRESERVE_SCALAR_STYLE
 /;
 use B;
 
 sub new {
     my ($class, %args) = @_;
+    my $preserve = delete $args{preserve} || 0;
+    if ($preserve == PRESERVE_ALL) {
+        $preserve = PRESERVE_ORDER | PRESERVE_SCALAR_STYLE;
+    }
     my $self = bless {
-        schema => $args{schema},
+        schema => delete $args{schema},
+        preserve => $preserve,
     }, $class;
+    if (keys %args) {
+        die "Unexpected arguments: " . join ', ', sort keys %args;
+    }
     return $self;
 }
 
@@ -28,18 +37,34 @@ sub clone {
     my ($self) = @_;
     my $clone = {
         schema => $self->schema,
+        preserve => $self->{preserve},
     };
     return bless $clone, ref $self;
 }
 
 sub schema { return $_[0]->{schema} }
+sub preserve_order { return $_[0]->{preserve} & PRESERVE_ORDER }
+sub preserve_scalar_style { return $_[0]->{preserve} & PRESERVE_SCALAR_STYLE }
 
 sub represent_node {
     my ($self, $node) = @_;
 
+    if ($self->preserve_scalar_style) {
+        if (ref $node->{value} eq 'YAML::PP::Preserve::Scalar') {
+            my $value = $node->{value}->value;
+            if ($node->{value}->style != YAML_FOLDED_SCALAR_STYLE) {
+                $node->{style} = $node->{value}->style;
+            }
+#            $node->{tag} = $node->{value}->tag;
+            $node->{value} = $value;
+        }
+    }
     $node->{reftype} = reftype($node->{value});
+    if (not $node->{reftype} and reftype(\$node->{value}) eq 'GLOB') {
+        $node->{reftype} = 'GLOB';
+    }
 
-    if (ref $node->{value}) {
+    if ($node->{reftype}) {
         $self->represent_noderef($node);
     }
     else {
@@ -59,7 +84,14 @@ sub represent_node {
     if ($node->{reftype} eq 'HASH') {
         unless (defined $node->{items}) {
             # by default we sort hash keys
-            for my $key (sort keys %{ $node->{data} }) {
+            my @keys;
+            if ($self->preserve_order) {
+                @keys = keys %{ $node->{data} };
+            }
+            else {
+                @keys = sort keys %{ $node->{data} };
+            }
+            for my $key (@keys) {
                 push @{ $node->{items} }, $key, $node->{data}->{ $key };
             }
         }
@@ -156,6 +188,10 @@ sub represent_noderef {
         my $code = $coderef->{code};
         return 1 if $code->($self, $node);
     }
+    if ($node->{reftype} eq 'GLOB' and my $glob = $representers->{glob}) {
+        my $code = $glob->{code};
+        return 1 if $code->($self, $node);
+    }
     $node->{data} = $node->{value};
 
 }
